@@ -75,9 +75,9 @@ bootstrap_model.merMod <- function(model, iterations = 1000, verbose = FALSE, ..
   }
 
   if (verbose) {
-    results <- suppressMessages(lme4::bootMer(model, boot_function, nsim = iterations, ...))
+    results <- suppressMessages(lme4::bootMer(model, boot_function, nsim = iterations, verbose = FALSE))
   } else {
-    results <- lme4::bootMer(model, boot_function, nsim = iterations, ...)
+    results <- lme4::bootMer(model, boot_function, nsim = iterations)
   }
 
   out <- as.data.frame(results$t)
